from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Poll(BaseModel):
    """
    types.Poll
    ID: 0x58747131
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Poll', 'Poll'] = pydantic.Field(
        'types.Poll',
        alias='_'
    )

    id: int
    question: "base.TextWithEntities"
    answers: list["base.PollAnswer"]
    closed: typing.Optional[bool] = None
    public_voters: typing.Optional[bool] = None
    multiple_choice: typing.Optional[bool] = None
    quiz: typing.Optional[bool] = None
    close_period: typing.Optional[int] = None
    close_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChannelParticipantsFilter - Layer 181
ChannelParticipantsFilter = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ChannelParticipantsAdmins, pydantic.Tag('ChannelParticipantsAdmins')],
        typing.Annotated[types.ChannelParticipantsBanned, pydantic.Tag('ChannelParticipantsBanned')],
        typing.Annotated[types.ChannelParticipantsBots, pydantic.Tag('ChannelParticipantsBots')],
        typing.Annotated[types.ChannelParticipantsContacts, pydantic.Tag('ChannelParticipantsContacts')],
        typing.Annotated[types.ChannelParticipantsKicked, pydantic.Tag('ChannelParticipantsKicked')],
        typing.Annotated[types.ChannelParticipantsMentions, pydantic.Tag('ChannelParticipantsMentions')],
        typing.Annotated[types.ChannelParticipantsRecent, pydantic.Tag('ChannelParticipantsRecent')],
        typing.Annotated[types.ChannelParticipantsSearch, pydantic.Tag('ChannelParticipantsSearch')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ResetPasswordRequestedWait(BaseModel):
    """
    types.account.ResetPasswordRequestedWait
    ID: 0xe9effc7d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.ResetPasswordRequestedWait', 'ResetPasswordRequestedWait'] = pydantic.Field(
        'types.account.ResetPasswordRequestedWait',
        alias='_'
    )

    until_date: Datetime



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CreateChat(BaseModel):
    """
    functions.messages.CreateChat
    ID: 0x92ceddd4
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.CreateChat', 'CreateChat'] = pydantic.Field(
        'functions.messages.CreateChat',
        alias='_'
    )

    users: list["base.InputUser"]
    title: str
    ttl_period: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputChatUploadedPhoto(BaseModel):
    """
    types.InputChatUploadedPhoto
    ID: 0xbdcdaec0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputChatUploadedPhoto', 'InputChatUploadedPhoto'] = pydantic.Field(
        'types.InputChatUploadedPhoto',
        alias='_'
    )

    file: typing.Optional["base.InputFile"] = None
    video: typing.Optional["base.InputFile"] = None
    video_start_ts: typing.Optional[float] = None
    video_emoji_markup: typing.Optional["base.VideoSize"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.Messages - Layer 181
Messages = typing.Annotated[
    typing.Union[
        typing.Annotated[types.messages.ChannelMessages, pydantic.Tag('messages.ChannelMessages')],
        typing.Annotated[types.messages.Messages, pydantic.Tag('messages.Messages')],
        typing.Annotated[types.messages.MessagesNotModified, pydantic.Tag('messages.MessagesNotModified')],
        typing.Annotated[types.messages.MessagesSlice, pydantic.Tag('messages.MessagesSlice')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Search(BaseModel):
    """
    functions.messages.Search
    ID: 0x29ee847a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.Search', 'Search'] = pydantic.Field(
        'functions.messages.Search',
        alias='_'
    )

    peer: "base.InputPeer"
    q: str
    filter: "base.MessagesFilter"
    min_date: Datetime
    max_date: Datetime
    offset_id: int
    add_offset: int
    limit: int
    max_id: int
    min_id: int
    hash: int
    from_id: typing.Optional["base.InputPeer"] = None
    saved_peer_id: typing.Optional["base.InputPeer"] = None
    saved_reaction: typing.Optional[list["base.Reaction"]] = None
    top_msg_id: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# RichText - Layer 181
RichText = typing.Annotated[
    typing.Union[
        typing.Annotated[types.TextAnchor, pydantic.Tag('TextAnchor')],
        typing.Annotated[types.TextBold, pydantic.Tag('TextBold')],
        typing.Annotated[types.TextConcat, pydantic.Tag('TextConcat')],
        typing.Annotated[types.TextEmail, pydantic.Tag('TextEmail')],
        typing.Annotated[types.TextEmpty, pydantic.Tag('TextEmpty')],
        typing.Annotated[types.TextFixed, pydantic.Tag('TextFixed')],
        typing.Annotated[types.TextImage, pydantic.Tag('TextImage')],
        typing.Annotated[types.TextItalic, pydantic.Tag('TextItalic')],
        typing.Annotated[types.TextMarked, pydantic.Tag('TextMarked')],
        typing.Annotated[types.TextPhone, pydantic.Tag('TextPhone')],
        typing.Annotated[types.TextPlain, pydantic.Tag('TextPlain')],
        typing.Annotated[types.TextStrike, pydantic.Tag('TextStrike')],
        typing.Annotated[types.TextSubscript, pydantic.Tag('TextSubscript')],
        typing.Annotated[types.TextSuperscript, pydantic.Tag('TextSuperscript')],
        typing.Annotated[types.TextUnderline, pydantic.Tag('TextUnderline')],
        typing.Annotated[types.TextUrl, pydantic.Tag('TextUrl')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionTopicEdit(BaseModel):
    """
    types.MessageActionTopicEdit
    ID: 0xc0944820
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionTopicEdit', 'MessageActionTopicEdit'] = pydantic.Field(
        'types.MessageActionTopicEdit',
        alias='_'
    )

    title: typing.Optional[str] = None
    icon_emoji_id: typing.Optional[int] = None
    closed: typing.Optional[bool] = None
    hidden: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputChannel - Layer 181
InputChannel = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputChannel, pydantic.Tag('InputChannel')],
        typing.Annotated[types.InputChannelEmpty, pydantic.Tag('InputChannelEmpty')],
        typing.Annotated[types.InputChannelFromMessage, pydantic.Tag('InputChannelFromMessage')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputSingleMedia(BaseModel):
    """
    types.InputSingleMedia
    ID: 0x1cc6e91f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputSingleMedia', 'InputSingleMedia'] = pydantic.Field(
        'types.InputSingleMedia',
        alias='_'
    )

    media: "base.InputMedia"
    random_id: int
    message: str
    entities: typing.Optional[list["base.MessageEntity"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessagesFilter - Layer 181
MessagesFilter = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputMessagesFilterChatPhotos, pydantic.Tag('InputMessagesFilterChatPhotos')],
        typing.Annotated[types.InputMessagesFilterContacts, pydantic.Tag('InputMessagesFilterContacts')],
        typing.Annotated[types.InputMessagesFilterDocument, pydantic.Tag('InputMessagesFilterDocument')],
        typing.Annotated[types.InputMessagesFilterEmpty, pydantic.Tag('InputMessagesFilterEmpty')],
        typing.Annotated[types.InputMessagesFilterGeo, pydantic.Tag('InputMessagesFilterGeo')],
        typing.Annotated[types.InputMessagesFilterGif, pydantic.Tag('InputMessagesFilterGif')],
        typing.Annotated[types.InputMessagesFilterMusic, pydantic.Tag('InputMessagesFilterMusic')],
        typing.Annotated[types.InputMessagesFilterMyMentions, pydantic.Tag('InputMessagesFilterMyMentions')],
        typing.Annotated[types.InputMessagesFilterPhoneCalls, pydantic.Tag('InputMessagesFilterPhoneCalls')],
        typing.Annotated[types.InputMessagesFilterPhotoVideo, pydantic.Tag('InputMessagesFilterPhotoVideo')],
        typing.Annotated[types.InputMessagesFilterPhotos, pydantic.Tag('InputMessagesFilterPhotos')],
        typing.Annotated[types.InputMessagesFilterPinned, pydantic.Tag('InputMessagesFilterPinned')],
        typing.Annotated[types.InputMessagesFilterRoundVideo, pydantic.Tag('InputMessagesFilterRoundVideo')],
        typing.Annotated[types.InputMessagesFilterRoundVoice, pydantic.Tag('InputMessagesFilterRoundVoice')],
        typing.Annotated[types.InputMessagesFilterUrl, pydantic.Tag('InputMessagesFilterUrl')],
        typing.Annotated[types.InputMessagesFilterVideo, pydantic.Tag('InputMessagesFilterVideo')],
        typing.Annotated[types.InputMessagesFilterVoice, pydantic.Tag('InputMessagesFilterVoice')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetWebPagePreview(BaseModel):
    """
    functions.messages.GetWebPagePreview
    ID: 0x8b68b0cc
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetWebPagePreview', 'GetWebPagePreview'] = pydantic.Field(
        'functions.messages.GetWebPagePreview',
        alias='_'
    )

    message: str
    entities: typing.Optional[list["base.MessageEntity"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessageEntity - Layer 181
MessageEntity = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputMessageEntityMentionName, pydantic.Tag('InputMessageEntityMentionName')],
        typing.Annotated[types.MessageEntityBankCard, pydantic.Tag('MessageEntityBankCard')],
        typing.Annotated[types.MessageEntityBlockquote, pydantic.Tag('MessageEntityBlockquote')],
        typing.Annotated[types.MessageEntityBold, pydantic.Tag('MessageEntityBold')],
        typing.Annotated[types.MessageEntityBotCommand, pydantic.Tag('MessageEntityBotCommand')],
        typing.Annotated[types.MessageEntityCashtag, pydantic.Tag('MessageEntityCashtag')],
        typing.Annotated[types.MessageEntityCode, pydantic.Tag('MessageEntityCode')],
        typing.Annotated[types.MessageEntityCustomEmoji, pydantic.Tag('MessageEntityCustomEmoji')],
        typing.Annotated[types.MessageEntityEmail, pydantic.Tag('MessageEntityEmail')],
        typing.Annotated[types.MessageEntityHashtag, pydantic.Tag('MessageEntityHashtag')],
        typing.Annotated[types.MessageEntityItalic, pydantic.Tag('MessageEntityItalic')],
        typing.Annotated[types.MessageEntityMention, pydantic.Tag('MessageEntityMention')],
        typing.Annotated[types.MessageEntityMentionName, pydantic.Tag('MessageEntityMentionName')],
        typing.Annotated[types.MessageEntityPhone, pydantic.Tag('MessageEntityPhone')],
        typing.Annotated[types.MessageEntityPre, pydantic.Tag('MessageEntityPre')],
        typing.Annotated[types.MessageEntitySpoiler, pydantic.Tag('MessageEntitySpoiler')],
        typing.Annotated[types.MessageEntityStrike, pydantic.Tag('MessageEntityStrike')],
        typing.Annotated[types.MessageEntityTextUrl, pydantic.Tag('MessageEntityTextUrl')],
        typing.Annotated[types.MessageEntityUnderline, pydantic.Tag('MessageEntityUnderline')],
        typing.Annotated[types.MessageEntityUnknown, pydantic.Tag('MessageEntityUnknown')],
        typing.Annotated[types.MessageEntityUrl, pydantic.Tag('MessageEntityUrl')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChannelParticipant - Layer 181
ChannelParticipant = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ChannelParticipant, pydantic.Tag('ChannelParticipant')],
        typing.Annotated[types.ChannelParticipantAdmin, pydantic.Tag('ChannelParticipantAdmin')],
        typing.Annotated[types.ChannelParticipantBanned, pydantic.Tag('ChannelParticipantBanned')],
        typing.Annotated[types.ChannelParticipantCreator, pydantic.Tag('ChannelParticipantCreator')],
        typing.Annotated[types.ChannelParticipantLeft, pydantic.Tag('ChannelParticipantLeft')],
        typing.Annotated[types.ChannelParticipantSelf, pydantic.Tag('ChannelParticipantSelf')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionGroupCallScheduled(BaseModel):
    """
    types.MessageActionGroupCallScheduled
    ID: 0xb3a07661
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionGroupCallScheduled', 'MessageActionGroupCallScheduled'] = pydantic.Field(
        'types.MessageActionGroupCallScheduled',
        alias='_'
    )

    call: "base.InputGroupCall"
    schedule_date: Datetime



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StoryReaction - Layer 181
StoryReaction = typing.Annotated[
    typing.Union[
        typing.Annotated[types.StoryReaction, pydantic.Tag('StoryReaction')],
        typing.Annotated[types.StoryReactionPublicForward, pydantic.Tag('StoryReactionPublicForward')],
        typing.Annotated[types.StoryReactionPublicRepost, pydantic.Tag('StoryReactionPublicRepost')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetInlineBotResults(BaseModel):
    """
    functions.messages.GetInlineBotResults
    ID: 0x514e999d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetInlineBotResults', 'GetInlineBotResults'] = pydantic.Field(
        'functions.messages.GetInlineBotResults',
        alias='_'
    )

    bot: "base.InputUser"
    peer: "base.InputPeer"
    query: str
    offset: str
    geo_point: typing.Optional["base.InputGeoPoint"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionSecureValuesSentMe(BaseModel):
    """
    types.MessageActionSecureValuesSentMe
    ID: 0x1b287353
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionSecureValuesSentMe', 'MessageActionSecureValuesSentMe'] = pydantic.Field(
        'types.MessageActionSecureValuesSentMe',
        alias='_'
    )

    values: list["base.SecureValue"]
    credentials: "base.SecureCredentialsEncrypted"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageEntityHashtag(BaseModel):
    """
    types.MessageEntityHashtag
    ID: 0x6f635b0d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageEntityHashtag', 'MessageEntityHashtag'] = pydantic.Field(
        'types.MessageEntityHashtag',
        alias='_'
    )

    offset: int
    length: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GeoPoint(BaseModel):
    """
    types.GeoPoint
    ID: 0xb2a2f663
    Layer: 181
    """
    QUALNAME: typing.Literal['types.GeoPoint', 'GeoPoint'] = pydantic.Field(
        'types.GeoPoint',
        alias='_'
    )

    long: float
    lat: float
    access_hash: int
    accuracy_radius: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputStorePaymentPremiumGiftCode(BaseModel):
    """
    types.InputStorePaymentPremiumGiftCode
    ID: 0xa3805f3f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputStorePaymentPremiumGiftCode', 'InputStorePaymentPremiumGiftCode'] = pydantic.Field(
        'types.InputStorePaymentPremiumGiftCode',
        alias='_'
    )

    users: list["base.InputUser"]
    currency: str
    amount: int
    boost_peer: typing.Optional["base.InputPeer"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaAreaChannelPost(BaseModel):
    """
    types.InputMediaAreaChannelPost
    ID: 0x2271f2bf
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaAreaChannelPost', 'InputMediaAreaChannelPost'] = pydantic.Field(
        'types.InputMediaAreaChannelPost',
        alias='_'
    )

    coordinates: "base.MediaAreaCoordinates"
    channel: "base.InputChannel"
    msg_id: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DocumentAttributeSticker(BaseModel):
    """
    types.DocumentAttributeSticker
    ID: 0x6319d612
    Layer: 181
    """
    QUALNAME: typing.Literal['types.DocumentAttributeSticker', 'DocumentAttributeSticker'] = pydantic.Field(
        'types.DocumentAttributeSticker',
        alias='_'
    )

    alt: str
    stickerset: "base.InputStickerSet"
    mask: typing.Optional[bool] = None
    mask_coords: typing.Optional["base.MaskCoords"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# contacts.TopPeers - Layer 181
TopPeers = typing.Annotated[
    typing.Union[
        typing.Annotated[types.contacts.TopPeers, pydantic.Tag('contacts.TopPeers')],
        typing.Annotated[types.contacts.TopPeersDisabled, pydantic.Tag('contacts.TopPeersDisabled')],
        typing.Annotated[types.contacts.TopPeersNotModified, pydantic.Tag('contacts.TopPeersNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChatInvite - Layer 181
ChatInvite = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ChatInvite, pydantic.Tag('ChatInvite')],
        typing.Annotated[types.ChatInviteAlready, pydantic.Tag('ChatInviteAlready')],
        typing.Annotated[types.ChatInvitePeek, pydantic.Tag('ChatInvitePeek')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StoriesStealthMode(BaseModel):
    """
    types.StoriesStealthMode
    ID: 0x712e27fd
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StoriesStealthMode', 'StoriesStealthMode'] = pydantic.Field(
        'types.StoriesStealthMode',
        alias='_'
    )

    active_until_date: typing.Optional[Datetime] = None
    cooldown_until_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BotBusinessConnection(BaseModel):
    """
    types.BotBusinessConnection
    ID: 0x896433b4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BotBusinessConnection', 'BotBusinessConnection'] = pydantic.Field(
        'types.BotBusinessConnection',
        alias='_'
    )

    connection_id: str
    user_id: int
    dc_id: int
    date: Datetime
    can_reply: typing.Optional[bool] = None
    disabled: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# payments.GiveawayInfo - Layer 181
GiveawayInfo = typing.Annotated[
    typing.Union[
        typing.Annotated[types.payments.GiveawayInfo, pydantic.Tag('payments.GiveawayInfo')],
        typing.Annotated[types.payments.GiveawayInfoResults, pydantic.Tag('payments.GiveawayInfoResults')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputFileLocation - Layer 181
InputFileLocation = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputDocumentFileLocation, pydantic.Tag('InputDocumentFileLocation')],
        typing.Annotated[types.InputEncryptedFileLocation, pydantic.Tag('InputEncryptedFileLocation')],
        typing.Annotated[types.InputFileLocation, pydantic.Tag('InputFileLocation')],
        typing.Annotated[types.InputGroupCallStream, pydantic.Tag('InputGroupCallStream')],
        typing.Annotated[types.InputPeerPhotoFileLocation, pydantic.Tag('InputPeerPhotoFileLocation')],
        typing.Annotated[types.InputPhotoFileLocation, pydantic.Tag('InputPhotoFileLocation')],
        typing.Annotated[types.InputPhotoLegacyFileLocation, pydantic.Tag('InputPhotoLegacyFileLocation')],
        typing.Annotated[types.InputSecureFileLocation, pydantic.Tag('InputSecureFileLocation')],
        typing.Annotated[types.InputStickerSetThumb, pydantic.Tag('InputStickerSetThumb')],
        typing.Annotated[types.InputTakeoutFileLocation, pydantic.Tag('InputTakeoutFileLocation')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# EncryptedChat - Layer 181
EncryptedChat = typing.Annotated[
    typing.Union[
        typing.Annotated[types.EncryptedChat, pydantic.Tag('EncryptedChat')],
        typing.Annotated[types.EncryptedChatDiscarded, pydantic.Tag('EncryptedChatDiscarded')],
        typing.Annotated[types.EncryptedChatEmpty, pydantic.Tag('EncryptedChatEmpty')],
        typing.Annotated[types.EncryptedChatRequested, pydantic.Tag('EncryptedChatRequested')],
        typing.Annotated[types.EncryptedChatWaiting, pydantic.Tag('EncryptedChatWaiting')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ThemeSettings(BaseModel):
    """
    types.ThemeSettings
    ID: 0xfa58b6d4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ThemeSettings', 'ThemeSettings'] = pydantic.Field(
        'types.ThemeSettings',
        alias='_'
    )

    base_theme: "base.BaseTheme"
    accent_color: int
    message_colors_animated: typing.Optional[bool] = None
    outbox_accent_color: typing.Optional[int] = None
    message_colors: typing.Optional[list[int]] = None
    wallpaper: typing.Optional["base.WallPaper"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BankCardData(BaseModel):
    """
    types.payments.BankCardData
    ID: 0x3e24e573
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.BankCardData', 'BankCardData'] = pydantic.Field(
        'types.payments.BankCardData',
        alias='_'
    )

    title: str
    open_urls: list["base.BankCardOpenUrl"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# RequestedPeer - Layer 181
RequestedPeer = typing.Annotated[
    typing.Union[
        typing.Annotated[types.RequestedPeerChannel, pydantic.Tag('RequestedPeerChannel')],
        typing.Annotated[types.RequestedPeerChat, pydantic.Tag('RequestedPeerChat')],
        typing.Annotated[types.RequestedPeerUser, pydantic.Tag('RequestedPeerUser')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelForbidden(BaseModel):
    """
    types.ChannelForbidden
    ID: 0x17d493d5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelForbidden', 'ChannelForbidden'] = pydantic.Field(
        'types.ChannelForbidden',
        alias='_'
    )

    id: int
    access_hash: int
    title: str
    broadcast: typing.Optional[bool] = None
    megagroup: typing.Optional[bool] = None
    until_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BusinessAwayMessageSchedule - Layer 181
BusinessAwayMessageSchedule = typing.Annotated[
    typing.Union[
        typing.Annotated[types.BusinessAwayMessageScheduleAlways, pydantic.Tag('BusinessAwayMessageScheduleAlways')],
        typing.Annotated[types.BusinessAwayMessageScheduleCustom, pydantic.Tag('BusinessAwayMessageScheduleCustom')],
        typing.Annotated[types.BusinessAwayMessageScheduleOutsideWorkHours, pydantic.Tag('BusinessAwayMessageScheduleOutsideWorkHours')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.AvailableEffects - Layer 181
AvailableEffects = typing.Annotated[
    typing.Union[
        typing.Annotated[types.messages.AvailableEffects, pydantic.Tag('messages.AvailableEffects')],
        typing.Annotated[types.messages.AvailableEffectsNotModified, pydantic.Tag('messages.AvailableEffectsNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetBotCallbackAnswer(BaseModel):
    """
    functions.messages.SetBotCallbackAnswer
    ID: 0xd58f130a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SetBotCallbackAnswer', 'SetBotCallbackAnswer'] = pydantic.Field(
        'functions.messages.SetBotCallbackAnswer',
        alias='_'
    )

    query_id: int
    cache_time: int
    alert: typing.Optional[bool] = None
    message: typing.Optional[str] = None
    url: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputStorePaymentPurpose - Layer 181
InputStorePaymentPurpose = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputStorePaymentGiftPremium, pydantic.Tag('InputStorePaymentGiftPremium')],
        typing.Annotated[types.InputStorePaymentPremiumGiftCode, pydantic.Tag('InputStorePaymentPremiumGiftCode')],
        typing.Annotated[types.InputStorePaymentPremiumGiveaway, pydantic.Tag('InputStorePaymentPremiumGiveaway')],
        typing.Annotated[types.InputStorePaymentPremiumSubscription, pydantic.Tag('InputStorePaymentPremiumSubscription')],
        typing.Annotated[types.InputStorePaymentStars, pydantic.Tag('InputStorePaymentStars')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionGroupCall(BaseModel):
    """
    types.MessageActionGroupCall
    ID: 0x7a0d7f42
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionGroupCall', 'MessageActionGroupCall'] = pydantic.Field(
        'types.MessageActionGroupCall',
        alias='_'
    )

    call: "base.InputGroupCall"
    duration: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GroupCall(BaseModel):
    """
    types.GroupCall
    ID: 0xd597650c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.GroupCall', 'GroupCall'] = pydantic.Field(
        'types.GroupCall',
        alias='_'
    )

    id: int
    access_hash: int
    participants_count: int
    unmuted_video_limit: int
    version: int
    join_muted: typing.Optional[bool] = None
    can_change_join_muted: typing.Optional[bool] = None
    join_date_asc: typing.Optional[bool] = None
    schedule_start_subscribed: typing.Optional[bool] = None
    can_start_video: typing.Optional[bool] = None
    record_video_active: typing.Optional[bool] = None
    rtmp_stream: typing.Optional[bool] = None
    listeners_hidden: typing.Optional[bool] = None
    title: typing.Optional[str] = None
    stream_dc_id: typing.Optional[int] = None
    record_start_date: typing.Optional[Datetime] = None
    schedule_date: typing.Optional[Datetime] = None
    unmuted_video_count: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BoostsStatus(BaseModel):
    """
    types.premium.BoostsStatus
    ID: 0x4959427a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.premium.BoostsStatus', 'BoostsStatus'] = pydantic.Field(
        'types.premium.BoostsStatus',
        alias='_'
    )

    level: int
    current_level_boosts: int
    boosts: int
    boost_url: str
    my_boost: typing.Optional[bool] = None
    gift_boosts: typing.Optional[int] = None
    next_level_boosts: typing.Optional[int] = None
    premium_audience: typing.Optional["base.StatsPercentValue"] = None
    prepaid_giveaways: typing.Optional[list["base.PrepaidGiveaway"]] = None
    my_boost_slots: typing.Optional[list[int]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateTheme(BaseModel):
    """
    types.UpdateTheme
    ID: 0x8216fba3
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateTheme', 'UpdateTheme'] = pydantic.Field(
        'types.UpdateTheme',
        alias='_'
    )

    theme: "base.Theme"



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.SentCodeType - Layer 181
SentCodeType = typing.Annotated[
    typing.Union[
        typing.Annotated[types.auth.SentCodeTypeApp, pydantic.Tag('auth.SentCodeTypeApp')],
        typing.Annotated[types.auth.SentCodeTypeCall, pydantic.Tag('auth.SentCodeTypeCall')],
        typing.Annotated[types.auth.SentCodeTypeEmailCode, pydantic.Tag('auth.SentCodeTypeEmailCode')],
        typing.Annotated[types.auth.SentCodeTypeFirebaseSms, pydantic.Tag('auth.SentCodeTypeFirebaseSms')],
        typing.Annotated[types.auth.SentCodeTypeFlashCall, pydantic.Tag('auth.SentCodeTypeFlashCall')],
        typing.Annotated[types.auth.SentCodeTypeFragmentSms, pydantic.Tag('auth.SentCodeTypeFragmentSms')],
        typing.Annotated[types.auth.SentCodeTypeMissedCall, pydantic.Tag('auth.SentCodeTypeMissedCall')],
        typing.Annotated[types.auth.SentCodeTypeSetUpEmailRequired, pydantic.Tag('auth.SentCodeTypeSetUpEmailRequired')],
        typing.Annotated[types.auth.SentCodeTypeSms, pydantic.Tag('auth.SentCodeTypeSms')],
        typing.Annotated[types.auth.SentCodeTypeSmsPhrase, pydantic.Tag('auth.SentCodeTypeSmsPhrase')],
        typing.Annotated[types.auth.SentCodeTypeSmsWord, pydantic.Tag('auth.SentCodeTypeSmsWord')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# updates.Difference - Layer 181
Difference = typing.Annotated[
    typing.Union[
        typing.Annotated[types.updates.Difference, pydantic.Tag('updates.Difference')],
        typing.Annotated[types.updates.DifferenceEmpty, pydantic.Tag('updates.DifferenceEmpty')],
        typing.Annotated[types.updates.DifferenceSlice, pydantic.Tag('updates.DifferenceSlice')],
        typing.Annotated[types.updates.DifferenceTooLong, pydantic.Tag('updates.DifferenceTooLong')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBusinessChatLink(BaseModel):
    """
    types.InputBusinessChatLink
    ID: 0x11679fa7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBusinessChatLink', 'InputBusinessChatLink'] = pydantic.Field(
        'types.InputBusinessChatLink',
        alias='_'
    )

    message: str
    entities: typing.Optional[list["base.MessageEntity"]] = None
    title: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.Authorization - Layer 181
Authorization = typing.Annotated[
    typing.Union[
        typing.Annotated[types.auth.Authorization, pydantic.Tag('auth.Authorization')],
        typing.Annotated[types.auth.AuthorizationSignUpRequired, pydantic.Tag('auth.AuthorizationSignUpRequired')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ClearRecentStickers(BaseModel):
    """
    functions.messages.ClearRecentStickers
    ID: 0x8999602d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.ClearRecentStickers', 'ClearRecentStickers'] = pydantic.Field(
        'functions.messages.ClearRecentStickers',
        alias='_'
    )

    attached: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetEmojiStickers(BaseModel):
    """
    functions.channels.SetEmojiStickers
    ID: 0x3cd930b7
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.SetEmojiStickers', 'SetEmojiStickers'] = pydantic.Field(
        'functions.channels.SetEmojiStickers',
        alias='_'
    )

    channel: "base.InputChannel"
    stickerset: "base.InputStickerSet"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StoryViews(BaseModel):
    """
    types.StoryViews
    ID: 0x8d595cd6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StoryViews', 'StoryViews'] = pydantic.Field(
        'types.StoryViews',
        alias='_'
    )

    views_count: int
    has_viewers: typing.Optional[bool] = None
    forwards_count: typing.Optional[int] = None
    reactions: typing.Optional[list["base.ReactionCount"]] = None
    reactions_count: typing.Optional[int] = None
    recent_viewers: typing.Optional[list[int]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateAutoSaveSettings(BaseModel):
    """
    types.UpdateAutoSaveSettings
    ID: 0xec05b097
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateAutoSaveSettings', 'UpdateAutoSaveSettings'] = pydantic.Field(
        'types.UpdateAutoSaveSettings',
        alias='_'
    )




from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageMediaPoll(BaseModel):
    """
    types.MessageMediaPoll
    ID: 0x4bd6e798
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageMediaPoll', 'MessageMediaPoll'] = pydantic.Field(
        'types.MessageMediaPoll',
        alias='_'
    )

    poll: "base.Poll"
    results: "base.PollResults"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EligibleToJoin(BaseModel):
    """
    types.smsjobs.EligibleToJoin
    ID: 0xdc8b44cf
    Layer: 181
    """
    QUALNAME: typing.Literal['types.smsjobs.EligibleToJoin', 'EligibleToJoin'] = pydantic.Field(
        'types.smsjobs.EligibleToJoin',
        alias='_'
    )

    terms_url: str
    monthly_sent_sms: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ForumTopic - Layer 181
ForumTopic = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ForumTopic, pydantic.Tag('ForumTopic')],
        typing.Annotated[types.ForumTopicDeleted, pydantic.Tag('ForumTopicDeleted')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AllStories(BaseModel):
    """
    types.stories.AllStories
    ID: 0x6efc5e81
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stories.AllStories', 'AllStories'] = pydantic.Field(
        'types.stories.AllStories',
        alias='_'
    )

    count: int
    state: str
    peer_stories: list["base.PeerStories"]
    chats: list["base.Chat"]
    users: list["base.User"]
    stealth_mode: "base.StoriesStealthMode"
    has_more: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# payments.PaymentResult - Layer 181
PaymentResult = typing.Annotated[
    typing.Union[
        typing.Annotated[types.payments.PaymentResult, pydantic.Tag('payments.PaymentResult')],
        typing.Annotated[types.payments.PaymentVerificationNeeded, pydantic.Tag('payments.PaymentVerificationNeeded')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Status(BaseModel):
    """
    types.smsjobs.Status
    ID: 0x2aee9191
    Layer: 181
    """
    QUALNAME: typing.Literal['types.smsjobs.Status', 'Status'] = pydantic.Field(
        'types.smsjobs.Status',
        alias='_'
    )

    recent_sent: int
    recent_since: Datetime
    recent_remains: int
    total_sent: int
    total_since: Datetime
    terms_url: str
    allow_international: typing.Optional[bool] = None
    last_gift_slug: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# JSONValue - Layer 181
JSONValue = typing.Annotated[
    typing.Union[
        typing.Annotated[types.JsonArray, pydantic.Tag('JsonArray')],
        typing.Annotated[types.JsonBool, pydantic.Tag('JsonBool')],
        typing.Annotated[types.JsonNull, pydantic.Tag('JsonNull')],
        typing.Annotated[types.JsonNumber, pydantic.Tag('JsonNumber')],
        typing.Annotated[types.JsonObject, pydantic.Tag('JsonObject')],
        typing.Annotated[types.JsonString, pydantic.Tag('JsonString')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputDocument - Layer 181
InputDocument = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputDocument, pydantic.Tag('InputDocument')],
        typing.Annotated[types.InputDocumentEmpty, pydantic.Tag('InputDocumentEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AutoSaveSettings(BaseModel):
    """
    types.AutoSaveSettings
    ID: 0xc84834ce
    Layer: 181
    """
    QUALNAME: typing.Literal['types.AutoSaveSettings', 'AutoSaveSettings'] = pydantic.Field(
        'types.AutoSaveSettings',
        alias='_'
    )

    photos: typing.Optional[bool] = None
    videos: typing.Optional[bool] = None
    video_max_size: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBotInlineResult(BaseModel):
    """
    types.InputBotInlineResult
    ID: 0x88bf9319
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBotInlineResult', 'InputBotInlineResult'] = pydantic.Field(
        'types.InputBotInlineResult',
        alias='_'
    )

    id: str
    type: str
    send_message: "base.InputBotInlineMessage"
    title: typing.Optional[str] = None
    description: typing.Optional[str] = None
    url: typing.Optional[str] = None
    thumb: typing.Optional["base.InputWebDocument"] = None
    content: typing.Optional["base.InputWebDocument"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendCode(BaseModel):
    """
    functions.auth.SendCode
    ID: 0xa677244f
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.SendCode', 'SendCode'] = pydantic.Field(
        'functions.auth.SendCode',
        alias='_'
    )

    phone_number: str
    api_id: int
    api_hash: str
    settings: "base.CodeSettings"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelAdminLogEventActionChangeUsernames(BaseModel):
    """
    types.ChannelAdminLogEventActionChangeUsernames
    ID: 0xf04fb3a9
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelAdminLogEventActionChangeUsernames', 'ChannelAdminLogEventActionChangeUsernames'] = pydantic.Field(
        'types.ChannelAdminLogEventActionChangeUsernames',
        alias='_'
    )

    prev_value: list[str]
    new_value: list[str]



from .is_eligible_to_join import IsEligibleToJoin
from .join import Join
from .leave import Leave
from .update_settings import UpdateSettings
from .get_status import GetStatus
from .get_sms_job import GetSmsJob
from .finish_job import FinishJob



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBotInlineResultGame(BaseModel):
    """
    types.InputBotInlineResultGame
    ID: 0x4fa417f2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBotInlineResultGame', 'InputBotInlineResultGame'] = pydantic.Field(
        'types.InputBotInlineResultGame',
        alias='_'
    )

    id: str
    short_name: str
    send_message: "base.InputBotInlineMessage"



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# AttachMenuPeerType - Layer 181
AttachMenuPeerType = typing.Annotated[
    typing.Union[
        typing.Annotated[types.AttachMenuPeerTypeBotPM, pydantic.Tag('AttachMenuPeerTypeBotPM')],
        typing.Annotated[types.AttachMenuPeerTypeBroadcast, pydantic.Tag('AttachMenuPeerTypeBroadcast')],
        typing.Annotated[types.AttachMenuPeerTypeChat, pydantic.Tag('AttachMenuPeerTypeChat')],
        typing.Annotated[types.AttachMenuPeerTypePM, pydantic.Tag('AttachMenuPeerTypePM')],
        typing.Annotated[types.AttachMenuPeerTypeSameBotPM, pydantic.Tag('AttachMenuPeerTypeSameBotPM')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MegagroupStats(BaseModel):
    """
    types.stats.MegagroupStats
    ID: 0xef7ff916
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stats.MegagroupStats', 'MegagroupStats'] = pydantic.Field(
        'types.stats.MegagroupStats',
        alias='_'
    )

    period: "base.StatsDateRangeDays"
    members: "base.StatsAbsValueAndPrev"
    messages: "base.StatsAbsValueAndPrev"
    viewers: "base.StatsAbsValueAndPrev"
    posters: "base.StatsAbsValueAndPrev"
    growth_graph: "base.StatsGraph"
    members_graph: "base.StatsGraph"
    new_members_by_source_graph: "base.StatsGraph"
    languages_graph: "base.StatsGraph"
    messages_graph: "base.StatsGraph"
    actions_graph: "base.StatsGraph"
    top_hours_graph: "base.StatsGraph"
    weekdays_graph: "base.StatsGraph"
    top_posters: list["base.StatsGroupTopPoster"]
    top_admins: list["base.StatsGroupTopAdmin"]
    top_inviters: list["base.StatsGroupTopInviter"]
    users: list["base.User"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types

# phone.GroupCallStreamRtmpUrl - Layer 181
# NOTICE: This is a workaround for pydantic. Discriminated unions doesn't work with single type in Union
# pydantic.Discriminator(base_type_discriminator)
GroupCallStreamRtmpUrl = typing.Union[
    typing.Annotated[types.phone.GroupCallStreamRtmpUrl, pydantic.Tag('phone.GroupCallStreamRtmpUrl')]
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.EmailVerified - Layer 181
EmailVerified = typing.Annotated[
    typing.Union[
        typing.Annotated[types.account.EmailVerified, pydantic.Tag('account.EmailVerified')],
        typing.Annotated[types.account.EmailVerifiedLogin, pydantic.Tag('account.EmailVerifiedLogin')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UserInfo(BaseModel):
    """
    types.help.UserInfo
    ID: 0x1eb3758
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.UserInfo', 'UserInfo'] = pydantic.Field(
        'types.help.UserInfo',
        alias='_'
    )

    message: str
    entities: list["base.MessageEntity"]
    author: str
    date: Datetime



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DialogFilterSuggested(BaseModel):
    """
    types.DialogFilterSuggested
    ID: 0x77744d4a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.DialogFilterSuggested', 'DialogFilterSuggested'] = pydantic.Field(
        'types.DialogFilterSuggested',
        alias='_'
    )

    filter: "base.DialogFilter"
    description: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ExportedChatInviteReplaced(BaseModel):
    """
    types.messages.ExportedChatInviteReplaced
    ID: 0x222600ef
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.ExportedChatInviteReplaced', 'ExportedChatInviteReplaced'] = pydantic.Field(
        'types.messages.ExportedChatInviteReplaced',
        alias='_'
    )

    invite: "base.ExportedChatInvite"
    new_invite: "base.ExportedChatInvite"
    users: list["base.User"]



from .payment_form import PaymentForm
from .validated_requested_info import ValidatedRequestedInfo
from .payment_result import PaymentResult
from .payment_receipt import PaymentReceipt
from .saved_info import SavedInfo
from .bank_card_data import BankCardData
from .exported_invoice import ExportedInvoice
from .checked_gift_code import CheckedGiftCode
from .giveaway_info import GiveawayInfo
from .stars_status import StarsStatus



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Reaction - Layer 181
Reaction = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ReactionCustomEmoji, pydantic.Tag('ReactionCustomEmoji')],
        typing.Annotated[types.ReactionEmoji, pydantic.Tag('ReactionEmoji')],
        typing.Annotated[types.ReactionEmpty, pydantic.Tag('ReactionEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PageBlock - Layer 181
PageBlock = typing.Annotated[
    typing.Union[
        typing.Annotated[types.PageBlockAnchor, pydantic.Tag('PageBlockAnchor')],
        typing.Annotated[types.PageBlockAudio, pydantic.Tag('PageBlockAudio')],
        typing.Annotated[types.PageBlockAuthorDate, pydantic.Tag('PageBlockAuthorDate')],
        typing.Annotated[types.PageBlockBlockquote, pydantic.Tag('PageBlockBlockquote')],
        typing.Annotated[types.PageBlockChannel, pydantic.Tag('PageBlockChannel')],
        typing.Annotated[types.PageBlockCollage, pydantic.Tag('PageBlockCollage')],
        typing.Annotated[types.PageBlockCover, pydantic.Tag('PageBlockCover')],
        typing.Annotated[types.PageBlockDetails, pydantic.Tag('PageBlockDetails')],
        typing.Annotated[types.PageBlockDivider, pydantic.Tag('PageBlockDivider')],
        typing.Annotated[types.PageBlockEmbed, pydantic.Tag('PageBlockEmbed')],
        typing.Annotated[types.PageBlockEmbedPost, pydantic.Tag('PageBlockEmbedPost')],
        typing.Annotated[types.PageBlockFooter, pydantic.Tag('PageBlockFooter')],
        typing.Annotated[types.PageBlockHeader, pydantic.Tag('PageBlockHeader')],
        typing.Annotated[types.PageBlockKicker, pydantic.Tag('PageBlockKicker')],
        typing.Annotated[types.PageBlockList, pydantic.Tag('PageBlockList')],
        typing.Annotated[types.PageBlockMap, pydantic.Tag('PageBlockMap')],
        typing.Annotated[types.PageBlockOrderedList, pydantic.Tag('PageBlockOrderedList')],
        typing.Annotated[types.PageBlockParagraph, pydantic.Tag('PageBlockParagraph')],
        typing.Annotated[types.PageBlockPhoto, pydantic.Tag('PageBlockPhoto')],
        typing.Annotated[types.PageBlockPreformatted, pydantic.Tag('PageBlockPreformatted')],
        typing.Annotated[types.PageBlockPullquote, pydantic.Tag('PageBlockPullquote')],
        typing.Annotated[types.PageBlockRelatedArticles, pydantic.Tag('PageBlockRelatedArticles')],
        typing.Annotated[types.PageBlockSlideshow, pydantic.Tag('PageBlockSlideshow')],
        typing.Annotated[types.PageBlockSubheader, pydantic.Tag('PageBlockSubheader')],
        typing.Annotated[types.PageBlockSubtitle, pydantic.Tag('PageBlockSubtitle')],
        typing.Annotated[types.PageBlockTable, pydantic.Tag('PageBlockTable')],
        typing.Annotated[types.PageBlockTitle, pydantic.Tag('PageBlockTitle')],
        typing.Annotated[types.PageBlockUnsupported, pydantic.Tag('PageBlockUnsupported')],
        typing.Annotated[types.PageBlockVideo, pydantic.Tag('PageBlockVideo')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StoryItem - Layer 181
StoryItem = typing.Annotated[
    typing.Union[
        typing.Annotated[types.StoryItem, pydantic.Tag('StoryItem')],
        typing.Annotated[types.StoryItemDeleted, pydantic.Tag('StoryItemDeleted')],
        typing.Annotated[types.StoryItemSkipped, pydantic.Tag('StoryItemSkipped')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdatePinnedMessages(BaseModel):
    """
    types.UpdatePinnedMessages
    ID: 0xed85eab5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdatePinnedMessages', 'UpdatePinnedMessages'] = pydantic.Field(
        'types.UpdatePinnedMessages',
        alias='_'
    )

    peer: "base.Peer"
    messages: list[int]
    pts: int
    pts_count: int
    pinned: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReorderPinnedDialogs(BaseModel):
    """
    functions.messages.ReorderPinnedDialogs
    ID: 0x3b1adf37
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.ReorderPinnedDialogs', 'ReorderPinnedDialogs'] = pydantic.Field(
        'functions.messages.ReorderPinnedDialogs',
        alias='_'
    )

    folder_id: int
    order: list["base.InputDialogPeer"]
    force: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WebPageAttributeStory(BaseModel):
    """
    types.WebPageAttributeStory
    ID: 0x2e94c3e7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WebPageAttributeStory', 'WebPageAttributeStory'] = pydantic.Field(
        'types.WebPageAttributeStory',
        alias='_'
    )

    peer: "base.Peer"
    id: int
    story: typing.Optional["base.StoryItem"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.CountriesList - Layer 181
CountriesList = typing.Annotated[
    typing.Union[
        typing.Annotated[types.help.CountriesList, pydantic.Tag('help.CountriesList')],
        typing.Annotated[types.help.CountriesListNotModified, pydantic.Tag('help.CountriesListNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageExtendedMediaPreview(BaseModel):
    """
    types.MessageExtendedMediaPreview
    ID: 0xad628cc8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageExtendedMediaPreview', 'MessageExtendedMediaPreview'] = pydantic.Field(
        'types.MessageExtendedMediaPreview',
        alias='_'
    )

    w: typing.Optional[int] = None
    h: typing.Optional[int] = None
    thumb: typing.Optional["base.PhotoSize"] = None
    video_duration: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# chatlists.ChatlistInvite - Layer 181
ChatlistInvite = typing.Annotated[
    typing.Union[
        typing.Annotated[types.chatlists.ChatlistInvite, pydantic.Tag('chatlists.ChatlistInvite')],
        typing.Annotated[types.chatlists.ChatlistInviteAlready, pydantic.Tag('chatlists.ChatlistInviteAlready')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Peer - Layer 181
Peer = typing.Annotated[
    typing.Union[
        typing.Annotated[types.PeerChannel, pydantic.Tag('PeerChannel')],
        typing.Annotated[types.PeerChat, pydantic.Tag('PeerChat')],
        typing.Annotated[types.PeerUser, pydantic.Tag('PeerUser')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotCallbackQuery(BaseModel):
    """
    types.UpdateBotCallbackQuery
    ID: 0xb9cfc48d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotCallbackQuery', 'UpdateBotCallbackQuery'] = pydantic.Field(
        'types.UpdateBotCallbackQuery',
        alias='_'
    )

    query_id: int
    user_id: int
    peer: "base.Peer"
    msg_id: int
    chat_instance: int
    data: typing.Optional[Bytes] = None
    game_short_name: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionPhoneCall(BaseModel):
    """
    types.MessageActionPhoneCall
    ID: 0x80e11a7f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionPhoneCall', 'MessageActionPhoneCall'] = pydantic.Field(
        'types.MessageActionPhoneCall',
        alias='_'
    )

    call_id: int
    video: typing.Optional[bool] = None
    reason: typing.Optional["base.PhoneCallDiscardReason"] = None
    duration: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputChatPhoto - Layer 181
InputChatPhoto = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputChatPhoto, pydantic.Tag('InputChatPhoto')],
        typing.Annotated[types.InputChatPhotoEmpty, pydantic.Tag('InputChatPhotoEmpty')],
        typing.Annotated[types.InputChatUploadedPhoto, pydantic.Tag('InputChatUploadedPhoto')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InvokeWithGooglePlayIntegrity(BaseModel):
    """
    functions.InvokeWithGooglePlayIntegrity
    ID: 0x1df92984
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.InvokeWithGooglePlayIntegrity', 'InvokeWithGooglePlayIntegrity'] = pydantic.Field(
        'functions.InvokeWithGooglePlayIntegrity',
        alias='_'
    )

    nonce: str
    token: str
    query: BaseModel



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# channels.ChannelParticipants - Layer 181
ChannelParticipants = typing.Annotated[
    typing.Union[
        typing.Annotated[types.channels.ChannelParticipants, pydantic.Tag('channels.ChannelParticipants')],
        typing.Annotated[types.channels.ChannelParticipantsNotModified, pydantic.Tag('channels.ChannelParticipantsNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ForwardMessages(BaseModel):
    """
    functions.messages.ForwardMessages
    ID: 0xd5039208
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.ForwardMessages', 'ForwardMessages'] = pydantic.Field(
        'functions.messages.ForwardMessages',
        alias='_'
    )

    from_peer: "base.InputPeer"
    id: list[int]
    random_id: list[int]
    to_peer: "base.InputPeer"
    silent: typing.Optional[bool] = None
    background: typing.Optional[bool] = None
    with_my_score: typing.Optional[bool] = None
    drop_author: typing.Optional[bool] = None
    drop_media_captions: typing.Optional[bool] = None
    noforwards: typing.Optional[bool] = None
    top_msg_id: typing.Optional[int] = None
    schedule_date: typing.Optional[Datetime] = None
    send_as: typing.Optional["base.InputPeer"] = None
    quick_reply_shortcut: typing.Optional["base.InputQuickReplyShortcut"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaAreaVenue(BaseModel):
    """
    types.InputMediaAreaVenue
    ID: 0xb282217f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaAreaVenue', 'InputMediaAreaVenue'] = pydantic.Field(
        'types.InputMediaAreaVenue',
        alias='_'
    )

    coordinates: "base.MediaAreaCoordinates"
    query_id: int
    result_id: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateChatUserTyping(BaseModel):
    """
    types.UpdateChatUserTyping
    ID: 0x83487af0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateChatUserTyping', 'UpdateChatUserTyping'] = pydantic.Field(
        'types.UpdateChatUserTyping',
        alias='_'
    )

    chat_id: int
    from_id: "base.Peer"
    action: "base.SendMessageAction"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BotInlineMessageMediaInvoice(BaseModel):
    """
    types.BotInlineMessageMediaInvoice
    ID: 0x354a9b09
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BotInlineMessageMediaInvoice', 'BotInlineMessageMediaInvoice'] = pydantic.Field(
        'types.BotInlineMessageMediaInvoice',
        alias='_'
    )

    title: str
    description: str
    currency: str
    total_amount: int
    shipping_address_requested: typing.Optional[bool] = None
    test: typing.Optional[bool] = None
    photo: typing.Optional["base.WebDocument"] = None
    reply_markup: typing.Optional["base.ReplyMarkup"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EmojiKeyword(BaseModel):
    """
    types.EmojiKeyword
    ID: 0xd5b3b9f9
    Layer: 181
    """
    QUALNAME: typing.Literal['types.EmojiKeyword', 'EmojiKeyword'] = pydantic.Field(
        'types.EmojiKeyword',
        alias='_'
    )

    keyword: str
    emoticons: list[str]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendAsPeer(BaseModel):
    """
    types.SendAsPeer
    ID: 0xb81c7034
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SendAsPeer', 'SendAsPeer'] = pydantic.Field(
        'types.SendAsPeer',
        alias='_'
    )

    peer: "base.Peer"
    premium_required: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SecureValue(BaseModel):
    """
    types.SecureValue
    ID: 0x187fa0ca
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SecureValue', 'SecureValue'] = pydantic.Field(
        'types.SecureValue',
        alias='_'
    )

    type: "base.SecureValueType"
    hash: Bytes
    data: typing.Optional["base.SecureData"] = None
    front_side: typing.Optional["base.SecureFile"] = None
    reverse_side: typing.Optional["base.SecureFile"] = None
    selfie: typing.Optional["base.SecureFile"] = None
    translation: typing.Optional[list["base.SecureFile"]] = None
    files: typing.Optional[list["base.SecureFile"]] = None
    plain_data: typing.Optional["base.SecurePlainData"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class JsonObject(BaseModel):
    """
    types.JsonObject
    ID: 0x99c1d49d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.JsonObject', 'JsonObject'] = pydantic.Field(
        'types.JsonObject',
        alias='_'
    )

    value: list["base.JSONObjectValue"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendWebViewData(BaseModel):
    """
    functions.messages.SendWebViewData
    ID: 0xdc0242c8
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SendWebViewData', 'SendWebViewData'] = pydantic.Field(
        'functions.messages.SendWebViewData',
        alias='_'
    )

    bot: "base.InputUser"
    random_id: int
    button_text: str
    data: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionTopicCreate(BaseModel):
    """
    types.MessageActionTopicCreate
    ID: 0xd999256
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionTopicCreate', 'MessageActionTopicCreate'] = pydantic.Field(
        'types.MessageActionTopicCreate',
        alias='_'
    )

    title: str
    icon_color: int
    icon_emoji_id: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateDcOptions(BaseModel):
    """
    types.UpdateDcOptions
    ID: 0x8e5e9873
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateDcOptions', 'UpdateDcOptions'] = pydantic.Field(
        'types.UpdateDcOptions',
        alias='_'
    )

    dc_options: list["base.DcOption"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputQuickReplyShortcut(BaseModel):
    """
    types.InputQuickReplyShortcut
    ID: 0x24596d41
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputQuickReplyShortcut', 'InputQuickReplyShortcut'] = pydantic.Field(
        'types.InputQuickReplyShortcut',
        alias='_'
    )

    shortcut: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# SecurePlainData - Layer 181
SecurePlainData = typing.Annotated[
    typing.Union[
        typing.Annotated[types.SecurePlainEmail, pydantic.Tag('SecurePlainEmail')],
        typing.Annotated[types.SecurePlainPhone, pydantic.Tag('SecurePlainPhone')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PollAnswerVoters(BaseModel):
    """
    types.PollAnswerVoters
    ID: 0x3b6ddad2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PollAnswerVoters', 'PollAnswerVoters'] = pydantic.Field(
        'types.PollAnswerVoters',
        alias='_'
    )

    option: Bytes
    voters: int
    chosen: typing.Optional[bool] = None
    correct: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AuthorizationSignUpRequired(BaseModel):
    """
    types.auth.AuthorizationSignUpRequired
    ID: 0x44747e9a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.auth.AuthorizationSignUpRequired', 'AuthorizationSignUpRequired'] = pydantic.Field(
        'types.auth.AuthorizationSignUpRequired',
        alias='_'
    )

    terms_of_service: typing.Optional["base.help.TermsOfService"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Support(BaseModel):
    """
    types.help.Support
    ID: 0x17c6b5f6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.Support', 'Support'] = pydantic.Field(
        'types.help.Support',
        alias='_'
    )

    phone_number: str
    user: "base.User"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputFileBig(BaseModel):
    """
    types.InputFileBig
    ID: 0xfa4f0bb5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputFileBig', 'InputFileBig'] = pydantic.Field(
        'types.InputFileBig',
        alias='_'
    )

    id: int
    parts: int
    name: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestEncryption(BaseModel):
    """
    functions.messages.RequestEncryption
    ID: 0xf64daf43
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.RequestEncryption', 'RequestEncryption'] = pydantic.Field(
        'functions.messages.RequestEncryption',
        alias='_'
    )

    user_id: "base.InputUser"
    random_id: int
    g_a: Bytes



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessagePeerVote - Layer 181
MessagePeerVote = typing.Annotated[
    typing.Union[
        typing.Annotated[types.MessagePeerVote, pydantic.Tag('MessagePeerVote')],
        typing.Annotated[types.MessagePeerVoteInputOption, pydantic.Tag('MessagePeerVoteInputOption')],
        typing.Annotated[types.MessagePeerVoteMultiple, pydantic.Tag('MessagePeerVoteMultiple')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UploadWallPaper(BaseModel):
    """
    functions.account.UploadWallPaper
    ID: 0xe39a8f03
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UploadWallPaper', 'UploadWallPaper'] = pydantic.Field(
        'functions.account.UploadWallPaper',
        alias='_'
    )

    file: "base.InputFile"
    mime_type: str
    settings: "base.WallPaperSettings"
    for_chat: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# WebPageAttribute - Layer 181
WebPageAttribute = typing.Annotated[
    typing.Union[
        typing.Annotated[types.WebPageAttributeStickerSet, pydantic.Tag('WebPageAttributeStickerSet')],
        typing.Annotated[types.WebPageAttributeStory, pydantic.Tag('WebPageAttributeStory')],
        typing.Annotated[types.WebPageAttributeTheme, pydantic.Tag('WebPageAttributeTheme')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdatePinnedMessage(BaseModel):
    """
    functions.messages.UpdatePinnedMessage
    ID: 0xd2aaf7ec
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.UpdatePinnedMessage', 'UpdatePinnedMessage'] = pydantic.Field(
        'functions.messages.UpdatePinnedMessage',
        alias='_'
    )

    peer: "base.InputPeer"
    id: int
    silent: typing.Optional[bool] = None
    unpin: typing.Optional[bool] = None
    pm_oneside: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StarsStatus(BaseModel):
    """
    types.payments.StarsStatus
    ID: 0x8cf4ee60
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.StarsStatus', 'StarsStatus'] = pydantic.Field(
        'types.payments.StarsStatus',
        alias='_'
    )

    balance: int
    history: list["base.StarsTransaction"]
    chats: list["base.Chat"]
    users: list["base.User"]
    next_offset: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelDifferenceEmpty(BaseModel):
    """
    types.updates.ChannelDifferenceEmpty
    ID: 0x3e11affb
    Layer: 181
    """
    QUALNAME: typing.Literal['types.updates.ChannelDifferenceEmpty', 'ChannelDifferenceEmpty'] = pydantic.Field(
        'types.updates.ChannelDifferenceEmpty',
        alias='_'
    )

    pts: int
    final: typing.Optional[bool] = None
    timeout: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotMenuButton(BaseModel):
    """
    types.UpdateBotMenuButton
    ID: 0x14b85813
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotMenuButton', 'UpdateBotMenuButton'] = pydantic.Field(
        'types.UpdateBotMenuButton',
        alias='_'
    )

    bot_id: int
    button: "base.BotMenuButton"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SecureValueErrorFiles(BaseModel):
    """
    types.SecureValueErrorFiles
    ID: 0x666220e9
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SecureValueErrorFiles', 'SecureValueErrorFiles'] = pydantic.Field(
        'types.SecureValueErrorFiles',
        alias='_'
    )

    type: "base.SecureValueType"
    file_hash: list[Bytes]
    text: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetStoriesArchive(BaseModel):
    """
    functions.stories.GetStoriesArchive
    ID: 0xb4352016
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stories.GetStoriesArchive', 'GetStoriesArchive'] = pydantic.Field(
        'functions.stories.GetStoriesArchive',
        alias='_'
    )

    peer: "base.InputPeer"
    offset_id: int
    limit: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class TranslateResult(BaseModel):
    """
    types.messages.TranslateResult
    ID: 0x33db32f8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.TranslateResult', 'TranslateResult'] = pydantic.Field(
        'types.messages.TranslateResult',
        alias='_'
    )

    result: list["base.TextWithEntities"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SearchResultsCalendarPeriod(BaseModel):
    """
    types.SearchResultsCalendarPeriod
    ID: 0xc9b0539f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SearchResultsCalendarPeriod', 'SearchResultsCalendarPeriod'] = pydantic.Field(
        'types.SearchResultsCalendarPeriod',
        alias='_'
    )

    date: Datetime
    min_msg_id: int
    max_msg_id: int
    count: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BindTempAuthKey(BaseModel):
    """
    functions.auth.BindTempAuthKey
    ID: 0xcdd42a05
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.BindTempAuthKey', 'BindTempAuthKey'] = pydantic.Field(
        'functions.auth.BindTempAuthKey',
        alias='_'
    )

    perm_auth_key_id: int
    nonce: int
    expires_at: Datetime
    encrypted_message: Bytes



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputPeerNotifySettings(BaseModel):
    """
    types.InputPeerNotifySettings
    ID: 0xcacb6ae2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputPeerNotifySettings', 'InputPeerNotifySettings'] = pydantic.Field(
        'types.InputPeerNotifySettings',
        alias='_'
    )

    show_previews: typing.Optional[bool] = None
    silent: typing.Optional[bool] = None
    mute_until: typing.Optional[Datetime] = None
    sound: typing.Optional["base.NotificationSound"] = None
    stories_muted: typing.Optional[bool] = None
    stories_hide_sender: typing.Optional[bool] = None
    stories_sound: typing.Optional["base.NotificationSound"] = None



from .update_profile_photo import UpdateProfilePhoto
from .upload_profile_photo import UploadProfilePhoto
from .delete_photos import DeletePhotos
from .get_user_photos import GetUserPhotos
from .upload_contact_profile_photo import UploadContactProfilePhoto



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InvokeWithLayer(BaseModel):
    """
    functions.InvokeWithLayer
    ID: 0xda9b0d0d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.InvokeWithLayer', 'InvokeWithLayer'] = pydantic.Field(
        'functions.InvokeWithLayer',
        alias='_'
    )

    layer: int
    query: BaseModel



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# payments.PaymentForm - Layer 181
PaymentForm = typing.Annotated[
    typing.Union[
        typing.Annotated[types.payments.PaymentForm, pydantic.Tag('payments.PaymentForm')],
        typing.Annotated[types.payments.PaymentFormStars, pydantic.Tag('payments.PaymentFormStars')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from .all_stories import AllStories
from .stories import Stories
from .story_views_list import StoryViewsList
from .story_views import StoryViews
from .peer_stories import PeerStories
from .story_reactions_list import StoryReactionsList



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StarsTransactionPeer - Layer 181
StarsTransactionPeer = typing.Annotated[
    typing.Union[
        typing.Annotated[types.StarsTransactionPeer, pydantic.Tag('StarsTransactionPeer')],
        typing.Annotated[types.StarsTransactionPeerAppStore, pydantic.Tag('StarsTransactionPeerAppStore')],
        typing.Annotated[types.StarsTransactionPeerFragment, pydantic.Tag('StarsTransactionPeerFragment')],
        typing.Annotated[types.StarsTransactionPeerPlayMarket, pydantic.Tag('StarsTransactionPeerPlayMarket')],
        typing.Annotated[types.StarsTransactionPeerPremiumBot, pydantic.Tag('StarsTransactionPeerPremiumBot')],
        typing.Annotated[types.StarsTransactionPeerUnsupported, pydantic.Tag('StarsTransactionPeerUnsupported')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ActivateStealthMode(BaseModel):
    """
    functions.stories.ActivateStealthMode
    ID: 0x57bbd166
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stories.ActivateStealthMode', 'ActivateStealthMode'] = pydantic.Field(
        'functions.stories.ActivateStealthMode',
        alias='_'
    )

    past: typing.Optional[bool] = None
    future: typing.Optional[bool] = None
